#ifndef _GPIO_IMX27_LIB_H_
#define _GPIO_IMX27_LIB_H_

#define IMX27_GPIO_IO_BASE 0x10015000

#define SETUP_OK            0
#define SETUP_DEVMEM_FAIL   1
#define SETUP_MALLOC_FAIL   2
#define SETUP_MMAP_FAIL     3

#define HIGH    1
#define LOW     0

#define INPUT   0
#define OUTPUT  1

#define GPIO_BANK(pin)	((pin) >> 5)
#define GPIO_NUM(pin)	((pin) & 0x1F)

/* GPIO bank sizes */
#define IMX27_GPIO_A_NR		(32)
#define IMX27_GPIO_B_NR		(32)
#define IMX27_GPIO_C_NR		(32)
#define IMX27_GPIO_D_NR		(32)
#define IMX27_GPIO_E_NR		(32)

#define IMX27_GPIO_NEXT(__gpio) ((__gpio##_START)+(__gpio##_NR)+0)

enum imx27_gpio_number {
	IMX27_GPIO_A_START = 0,
	IMX27_GPIO_B_START = IMX27_GPIO_NEXT(IMX27_GPIO_A),	//32
	IMX27_GPIO_C_START = IMX27_GPIO_NEXT(IMX27_GPIO_B),	//64
	IMX27_GPIO_D_START = IMX27_GPIO_NEXT(IMX27_GPIO_C),	//96
	IMX27_GPIO_E_START = IMX27_GPIO_NEXT(IMX27_GPIO_D),	//128
};

/* IMX27 GPIO number definitions */
#define IMX27_GPA(_nr) (IMX27_GPIO_A_START + (_nr))
#define IMX27_GPB(_nr) (IMX27_GPIO_B_START + (_nr))
#define IMX27_GPC(_nr) (IMX27_GPIO_C_START + (_nr))
#define IMX27_GPD(_nr) (IMX27_GPIO_D_START + (_nr))
#define IMX27_GPE(_nr) (IMX27_GPIO_E_START + (_nr))
#define IMX27_GPF(_nr) (IMX27_GPIO_F_START + (_nr))
#define IMX27_GPG(_nr) (IMX27_GPIO_G_START + (_nr))
#define IMX27_GPH(_nr) (IMX27_GPIO_H_START + (_nr))
#define IMX27_GPI(_nr) (IMX27_GPIO_I_START + (_nr))

extern int imx27_gpio_input(unsigned int pin);
extern int imx27_gpio_init(void);
extern int imx27_gpio_set_cfgpin(unsigned int pin, unsigned int val);
extern int imx27_gpio_get_cfgpin(unsigned int pin);
extern int imx27_gpio_output(unsigned int pin, unsigned int val);
extern void imx27_gpio_cleanup(void);

//extern unsigned int IMX27_PIO_BASE;
#endif
